pub struct Config {
pub tx_cost_limit: u64,
pub eviction_memory_time: Duration,
pub debug_enable_at_height: Option<u32>,
pub max_datacarrier_bytes: Option<u32>,
}Expand description
Mempool configuration section.
Fields
tx_cost_limit: u64The mempool transaction cost limit.
This limits the total serialized byte size of all transactions in the mempool.
Consensus rule:
There MUST be a configuration option mempooltxcostlimit, which SHOULD default to 80000000.
This corresponds to mempooltxcostlimit from ZIP-401.
eviction_memory_time: DurationThe mempool transaction eviction age limit.
This limits the maximum amount of time evicted transaction IDs stay in
the mempool rejection list. Transactions are randomly evicted from the
mempool when the mempool reaches Self::tx_cost_limit.
(Transactions can also be rejected by the mempool for other reasons. Different rejection reasons can have different age limits.)
This corresponds to mempoolevictionmemoryminutes from
ZIP-401.
debug_enable_at_height: Option<u32>If the state’s best chain tip has reached this height, always enable the mempool, regardless of Zebra’s sync status.
Set to None by default: Zebra always checks the sync status before enabling the mempool.
max_datacarrier_bytes: Option<u32>Maximum size in bytes of an OP_RETURN script that is considered standard.
If unset, defaults to DEFAULT_MAX_DATACARRIER_BYTES. This size includes the OP_RETURN
opcode and pushdata overhead. Matches zcashd’s -datacarriersize default behavior.